import { createStore, reconcile } from 'solid-js/store';
import { createSignal, createEffect, For, onCleanup } from 'solid-js';
import { create, PDFSlick } from '@pdfslick/core';
export * from '@pdfslick/core';
import { use, effect, className, template, insert, createComponent, Portal, classList } from 'solid-js/web';
import { createElementSize } from '@solid-primitives/resize-observer';

var _tmpl$$1 = /*#__PURE__*/template(`<div id=viewerContainer><div id=viewer class="pdfSlickViewer pdfViewer">`);
function PDFSlickViewer(props) {
  const [resizeRef, setResizeRef] = createSignal();
  const size = createElementSize(resizeRef);
  createEffect(() => {
    if (size.width && size.height) {
      if (props.store.pdfSlick && (props.store.scaleValue === "auto" || props.store.scaleValue === "page-fit" || props.store.scaleValue === "page-width")) {
        props.store.pdfSlick.viewer.currentScaleValue = props.store.scaleValue;
      }
      props.store.pdfSlick?.viewer.update();
    }
  });
  return (() => {
    var _el$ = _tmpl$$1();
    use(el => {
      props.viewerRef(el);
      setResizeRef(el);
    }, _el$);
    _el$.style.setProperty("position", "absolute");
    _el$.style.setProperty("inset", "0");
    effect(() => className(_el$, `pdfSlickContainer ${props.class ?? ""}`));
    return _el$;
  })();
}

var _tmpl$ = /*#__PURE__*/template(`<div>`);
function PDFSlickThumbnails(props) {
  const [resizeRef, setResizeRef] = createSignal();
  const size = createElementSize(resizeRef);
  createEffect(() => {
    if (size.width && size.height) {
      props.store.pdfSlick?.forceRendering();
    }
  });
  return (() => {
    var _el$ = _tmpl$();
    use(el => {
      props.thumbsRef(el);
      setResizeRef(el);
    }, _el$);
    _el$.style.setProperty("position", "absolute");
    _el$.style.setProperty("overflow", "auto");
    _el$.style.setProperty("inset", "0");
    insert(_el$, createComponent(For, {
      get each() {
        return Array.from(props.store.thumbnailViews);
      },
      children: ([pageNumber, view]) => createComponent(Portal, {
        get mount() {
          return view.div;
        },
        get children() {
          return props.children({
            pageNumber,
            width: view.canvasWidth,
            height: view.canvasHeight,
            scale: view.scale,
            src: view?.src ?? null,
            rotation: view.rotation,
            pageLabel: view.pageLabel,
            loaded: view.loaded
          });
        }
      })
    }));
    effect(_p$ => {
      var _v$ = props.class ?? "",
        _v$2 = props.classList ?? {};
      _v$ !== _p$.e && className(_el$, _p$.e = _v$);
      _p$.t = classList(_el$, _v$2, _p$.t);
      return _p$;
    }, {
      e: undefined,
      t: undefined
    });
    return _el$;
  })();
}

function useStore(api, selector = api.getState, equalityFn) {
  const initialValue = selector(api.getState());
  const [state, setState] = createStore(initialValue);
  const listener = (nextState, previousState) => {
    selector(previousState);
    const nextStateSlice = selector(nextState);
    {
      setState(reconcile(nextStateSlice));
    }
  };
  const unsubscribe = api.subscribe(listener);
  onCleanup(() => unsubscribe());
  return state;
}
const usePDFSlick = (url, options) => {
  const [isDocumentLoaded, setIsDocumentLoaded] = createSignal(false);
  const [areContainersMounted, setContainersMounted] = createSignal(false);
  const [container, setContainer] = createSignal(null);
  const [thumbs, setThumbs] = createSignal(null);
  const [error, setError] = createSignal(null);
  const [pdfSlick, setPdfSlick] = createSignal(null);
  const zustandStore = create();
  const pdfSlickStore = useStore(zustandStore);
  const viewerRef = node => {
    setContainer(node);
    setContainersMounted(true);
  };
  const thumbsRef = node => {
    setThumbs(node);
  };
  createEffect(() => {
    if (url && areContainersMounted()) {
      const pdfSlick = new PDFSlick({
        container: container(),
        thumbs: thumbs(),
        store: zustandStore,
        options,
        onError: err => setError(err)
      });
      setPdfSlick(pdfSlick);
      zustandStore.setState({
        pdfSlick
      });
      pdfSlick.loadDocument(url, options).then(() => {
        setIsDocumentLoaded(true);
      });
    }
  });
  return {
    isDocumentLoaded,
    viewerRef,
    thumbsRef,
    pdfSlick,
    pdfSlickStore,
    PDFSlickViewer,
    PDFSlickThumbnails,
    error
  };
};

export { PDFSlickThumbnails, usePDFSlick };
//# sourceMappingURL=index.js.map
